@@ -160,16 +160,19 @@ def parse_flir_chunk(
     chunks_tot = int.from_bytes(stream.read(chunk_tot_bytes_count), "big")
 
     # Remember total chunks to verify metadata consistency
-    if not chunks_count:
+    if chunks_count is None:
         chunks_count = chunks_tot
 
     if (  # Check whether chunk metadata is consistent
-        not chunks_tot
+        chunks_tot is None
         or chunk_num < 0
         or chunk_num > chunks_tot
         or chunks_tot != chunks_count
     ):
-        raise ValueError("Invalid FLIR: inconsistent total chunks")
+        raise ValueError(
+            f"Invalid FLIR: inconsistent total chunks, should be 0 or greater, "
+            "but is {chunks_tot}"
+        )
 
     # FIXME There is  calculation error somewhere which causes length to be
     #       1 too small. So far it manually adding 1 seems sufficient to
